.. kayobe documentation master file, created by
   sphinx-quickstart on Tue Jul  9 22:26:36 2013.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Kayobe's documentation!
==================================

.. include:: ../../README.rst

Documentation
-------------

.. note::

   Kayobe and its documentation is currently under heavy development, and
   therefore may be incomplete or out of date.  If in doubt, contact the
   project's maintainers.

.. toctree::
   :maxdepth: 2

   architecture
   installation
   usage
   configuration/index
   deployment
   upgrading
   administration/index

Advanced Documentation
----------------------

.. toctree::
   :maxdepth: 2

   control-plane-service-placement
   custom-ansible-playbooks

Developer Documentation
-----------------------

.. toctree::
   :maxdepth: 2

   development/index
